Author: gabor
Date: Wed Apr 17 11:40:10 2013
New Revision: 249582
URL: http://svnweb.freebsd.org/changeset/base/249582

Log:
  - Correct mispellings of the word occurrence
  
  Submitted by: Christoph Mallon <christoph.mal...@gmx.de> (via private mail)

Modified:
  head/lib/libc/i386/string/memchr.S
  head/lib/libc/i386/string/strchr.S
  head/lib/libc/i386/string/strrchr.S
  head/lib/libc/stdlib/realpath.c
  head/lib/libz/zlib.h
  head/sys/arm/include/sysarch.h
  head/sys/arm/xscale/ixp425/ixp425_npe.c
  head/sys/cam/scsi/scsi_pass.c
  head/sys/cam/scsi/scsi_target.c
  head/sys/dev/cxgb/common/cxgb_t3_hw.c
  head/sys/dev/msk/if_msk.c
  head/sys/dev/ppbus/ppbconf.c
  head/sys/dev/rndtest/rndtest.c
  head/sys/kern/vfs_mount.c
  head/sys/ufs/ffs/ffs_balloc.c
  head/tools/regression/usr.bin/yacc/grammar.y
  head/tools/regression/usr.bin/yacc/regress.08.out
  head/usr.sbin/ppp/command.c

Modified: head/lib/libc/i386/string/memchr.S
==============================================================================
--- head/lib/libc/i386/string/memchr.S  Wed Apr 17 09:19:29 2013        
(r249581)
+++ head/lib/libc/i386/string/memchr.S  Wed Apr 17 11:40:10 2013        
(r249582)
@@ -33,7 +33,7 @@ __FBSDID("$FreeBSD$");
 
 /*
  * memchr (b, c, len)
- *     locates the first occurance of c in string b.
+ *     locates the first occurrence of c in string b.
  *
  * Written by:
  *     J.T. Conklin (j...@wimsey.com), Winning Strategies, Inc.

Modified: head/lib/libc/i386/string/strchr.S
==============================================================================
--- head/lib/libc/i386/string/strchr.S  Wed Apr 17 09:19:29 2013        
(r249581)
+++ head/lib/libc/i386/string/strchr.S  Wed Apr 17 11:40:10 2013        
(r249582)
@@ -33,11 +33,11 @@ __FBSDID("$FreeBSD$");
 
 /*
  * strchr(s, c)
- *     return a pointer to the first occurance of the character c in
+ *     return a pointer to the first occurrence of the character c in
  *     string s, or NULL if c does not occur in the string.
  *
  * %edx - pointer iterating through string
- * %eax - pointer to first occurance of 'c'
+ * %eax - pointer to first occurrence of 'c'
  * %cl  - character we're comparing against
  * %bl  - character at %edx
  *

Modified: head/lib/libc/i386/string/strrchr.S
==============================================================================
--- head/lib/libc/i386/string/strrchr.S Wed Apr 17 09:19:29 2013        
(r249581)
+++ head/lib/libc/i386/string/strrchr.S Wed Apr 17 11:40:10 2013        
(r249582)
@@ -33,11 +33,11 @@ __FBSDID("$FreeBSD$");
 
 /*
  * strrchr(s, c)
- *     return a pointer to the last occurance of the character c in
+ *     return a pointer to the last occurrence of the character c in
  *     string s, or NULL if c does not occur in the string.
  *
  * %edx - pointer iterating through string
- * %eax - pointer to last occurance of 'c'
+ * %eax - pointer to last occurrence of 'c'
  * %cl  - character we're comparing against
  * %bl  - character at %edx
  *

Modified: head/lib/libc/stdlib/realpath.c
==============================================================================
--- head/lib/libc/stdlib/realpath.c     Wed Apr 17 09:19:29 2013        
(r249581)
+++ head/lib/libc/stdlib/realpath.c     Wed Apr 17 11:40:10 2013        
(r249582)
@@ -139,7 +139,7 @@ realpath(const char * __restrict path, c
                         * Only the trailing slashes are not covered
                         * by other checks in the loop, but we verify
                         * the prefix for any (rare) "//" or "/\0"
-                        * occurence to not implement lookahead.
+                        * occurrence to not implement lookahead.
                         */
                        if (lstat(resolved, &sb) != 0) {
                                if (m)

Modified: head/lib/libz/zlib.h
==============================================================================
--- head/sys/dev/msk/if_msk.c   Wed Apr 17 09:19:29 2013        (r249581)
+++ head/sys/dev/msk/if_msk.c   Wed Apr 17 11:40:10 2013        (r249582)
@@ -3526,7 +3526,7 @@ msk_intr_hwerr(struct msk_softc *sc)
                 * On PCI Express bus bridges are called root complexes (RC).
                 * PCI Express errors are recognized by the root complex too,
                 * which requests the system to handle the problem. After
-                * error occurence it may be that no access to the adapter
+                * error occurrence it may be that no access to the adapter
                 * may be performed any longer.
                 */
 

Modified: head/sys/dev/ppbus/ppbconf.c
==============================================================================
--- head/sys/dev/ppbus/ppbconf.c        Wed Apr 17 09:19:29 2013        
(r249581)
+++ head/sys/dev/ppbus/ppbconf.c        Wed Apr 17 11:40:10 2013        
(r249582)
@@ -172,7 +172,7 @@ static char *pnp_classes[] = {
 /*
  * search_token()
  *
- * Search the first occurence of a token within a string
+ * Search the first occurrence of a token within a string
  */
 static char *
 search_token(char *str, int slen, char *token)

Modified: head/sys/dev/rndtest/rndtest.c
==============================================================================
--- head/sys/dev/rndtest/rndtest.c      Wed Apr 17 09:19:29 2013        
(r249581)
+++ head/sys/dev/rndtest/rndtest.c      Wed Apr 17 11:40:10 2013        
(r249582)
@@ -360,7 +360,7 @@ rndtest_chi_4(struct rndtest_state *rsp)
        for (i = 0; i < RNDTEST_CHI4_K; i++)
                freq[i] = 0;
 
-       /* Get number of occurances of each 4 bit pattern */
+       /* Get number of occurrences of each 4 bit pattern */
        for (i = 0; i < RNDTEST_NBYTES; i++) {
                freq[(rsp->rs_buf[i] >> 4) & RNDTEST_CHI4_K_MASK]++;
                freq[(rsp->rs_buf[i] >> 0) & RNDTEST_CHI4_K_MASK]++;

Modified: head/sys/kern/vfs_mount.c
==============================================================================
--- head/sys/kern/vfs_mount.c   Wed Apr 17 09:19:29 2013        (r249581)
+++ head/sys/kern/vfs_mount.c   Wed Apr 17 11:40:10 2013        (r249582)
@@ -232,7 +232,7 @@ vfs_equalopts(const char *opt1, const ch
 /*
  * If a mount option is specified several times,
  * (with or without the "no" prefix) only keep
- * the last occurence of it.
+ * the last occurrence of it.
  */
 static void
 vfs_sanitizeopts(struct vfsoptlist *opts)

Modified: head/sys/ufs/ffs/ffs_balloc.c
==============================================================================
--- head/sys/ufs/ffs/ffs_balloc.c       Wed Apr 17 09:19:29 2013        
(r249581)
+++ head/sys/ufs/ffs/ffs_balloc.c       Wed Apr 17 11:40:10 2013        
(r249582)
@@ -453,7 +453,7 @@ fail:
         * We have to sync it at the end so that the soft updates code
         * does not find any untracked changes. Although this is really
         * slow, running out of disk space is not expected to be a common
-        * occurence. The error return from fsync is ignored as we already
+        * occurrence. The error return from fsync is ignored as we already
         * have an error to return to the user.
         *
         * XXX Still have to journal the free below

Modified: head/tools/regression/usr.bin/yacc/grammar.y
==============================================================================
--- head/tools/regression/usr.bin/yacc/grammar.y        Wed Apr 17 09:19:29 
2013        (r249581)
+++ head/tools/regression/usr.bin/yacc/grammar.y        Wed Apr 17 11:40:10 
2013        (r249582)
@@ -1027,7 +1027,7 @@ extern char *yytext;
 extern FILE *yyin, *yyout;
 
 static int curly;                      /* number of curly brace nesting levels 
*/
-static int ly_count;                   /* number of occurances of %% */
+static int ly_count;                   /* number of occurrences of %% */
 static int inc_depth;                  /* include nesting level */
 static SymbolTable *included_files;    /* files already included */
 static int yy_start = 0;               /* start state number */

Modified: head/tools/regression/usr.bin/yacc/regress.08.out
==============================================================================
--- head/tools/regression/usr.bin/yacc/regress.08.out   Wed Apr 17 09:19:29 
2013        (r249581)
+++ head/tools/regression/usr.bin/yacc/regress.08.out   Wed Apr 17 11:40:10 
2013        (r249582)
@@ -847,7 +847,7 @@ extern char *yytext;
 extern FILE *yyin, *yyout;
 
 static int curly;                      /* number of curly brace nesting levels 
*/
-static int ly_count;                   /* number of occurances of %% */
+static int ly_count;                   /* number of occurrences of %% */
 static int inc_depth;                  /* include nesting level */
 static SymbolTable *included_files;    /* files already included */
 static int yy_start = 0;               /* start state number */

Modified: head/usr.sbin/ppp/command.c
==============================================================================
--- head/usr.sbin/ppp/command.c Wed Apr 17 09:19:29 2013        (r249581)
+++ head/usr.sbin/ppp/command.c Wed Apr 17 11:40:10 2013        (r249582)
@@ -416,7 +416,7 @@ DialCommand(struct cmdargs const *arg)
 static char *
 strstrword(char *big, const char *little)
 {
-  /* Get the first occurrance of the word ``little'' in ``big'' */
+  /* Get the first occurrence of the word ``little'' in ``big'' */
   char *pos;
   int len;
 
_______________________________________________
svn-src-all@freebsd.org mailing list
http://lists.freebsd.org/mailman/listinfo/svn-src-all
To unsubscribe, send any mail to "svn-src-all-unsubscr...@freebsd.org"

Reply via email to
--- head/lib/libz/zlib.h        Wed Apr 17 09:19:29 2013        (r249581)
+++ head/lib/libz/zlib.h        Wed Apr 17 11:40:10 2013        (r249582)
@@ -846,7 +846,7 @@ ZEXTERN int ZEXPORT inflateSync OF((z_st
    available input is skipped.  No output is provided.
 
      inflateSync searches for a 00 00 FF FF pattern in the compressed data.
-   All full flush points have this pattern, but not all occurences of this
+   All full flush points have this pattern, but not all occurrences of this
    pattern are full flush points.
 
      inflateSync returns Z_OK if a possible full flush point has been found,

Modified: head/sys/arm/include/sysarch.h
==============================================================================
--- head/sys/arm/include/sysarch.h      Wed Apr 17 09:19:29 2013        
(r249581)
+++ head/sys/arm/include/sysarch.h      Wed Apr 17 11:40:10 2013        
(r249582)
@@ -47,7 +47,7 @@
  * update the cpu_switch() (and cpu_throw()) code as well.
  * In addition, code in arm/include/atomic.h and arm/include/asmacros.h
  * assumes that ARM_RAS_END is at ARM_RAS_START+4, so be sure to update those
- * if ARM_RAS_END moves in relation to ARM_RAS_START (look for occurrances
+ * if ARM_RAS_END moves in relation to ARM_RAS_START (look for occurrences
  * of ldr/str rm,[rn, #4]).
  */
 

Modified: head/sys/arm/xscale/ixp425/ixp425_npe.c
==============================================================================
--- head/sys/arm/xscale/ixp425/ixp425_npe.c     Wed Apr 17 09:19:29 2013        
(r249581)
+++ head/sys/arm/xscale/ixp425/ixp425_npe.c     Wed Apr 17 11:40:10 2013        
(r249582)
@@ -419,7 +419,7 @@ ixpnpe_stop(struct ixpnpe_softc *sc)
 
 /*
  * Indicates the start of an NPE Image, in new NPE Image Library format.
  * 2 consecutive occurances indicates the end of the NPE Image Library
  */
 #define NPE_IMAGE_MARKER 0xfeedf00d
 

Modified: head/sys/cam/scsi/scsi_pass.c
==============================================================================
--- head/sys/cam/scsi/scsi_pass.c       Wed Apr 17 09:19:29 2013        
(r249581)
+++ head/sys/cam/scsi/scsi_pass.c       Wed Apr 17 11:40:10 2013        
(r249582)
@@ -694,7 +694,7 @@ passsendccb(struct cam_periph *periph, u
         * match CCBs.  For the SCSI, ATA and ADVINFO CCBs, we only pass the
         * CCB in if there's actually data to map.  cam_periph_mapmem() will
         * do the right thing, even if there isn't data to map, but since CCBs
-        * without data are a reasonably common occurance (e.g. test unit
+        * without data are a reasonably common occurrence (e.g. test unit
         * ready), it will save a few cycles if we check for it here.
         *
         * XXX What happens if a sg list is supplied?  We don't filter that

Modified: head/sys/cam/scsi/scsi_target.c
==============================================================================
--- head/sys/cam/scsi/scsi_target.c     Wed Apr 17 09:19:29 2013        
(r249581)
+++ head/sys/cam/scsi/scsi_target.c     Wed Apr 17 11:40:10 2013        
(r249582)
@@ -734,7 +734,7 @@ targsendccb(struct targ_softc *softc, un
         * match CCBs.  For the SCSI CCBs, we only pass the CCB in if
         * there's actually data to map.  cam_periph_mapmem() will do the
         * right thing, even if there isn't data to map, but since CCBs
-        * without data are a reasonably common occurance (e.g. test unit
+        * without data are a reasonably common occurrence (e.g. test unit
         * ready), it will save a few cycles if we check for it here.
         */
        if (((ccb_h->flags & CAM_DATA_MASK) == CAM_DATA_VADDR)

Modified: head/sys/dev/cxgb/common/cxgb_t3_hw.c
==============================================================================
--- head/sys/dev/cxgb/common/cxgb_t3_hw.c       Wed Apr 17 09:19:29 2013        
(r249581)
+++ head/sys/dev/cxgb/common/cxgb_t3_hw.c       Wed Apr 17 11:40:10 2013        
(r249582)
@@ -1727,7 +1727,7 @@ struct intr_info {
  *     @reg: the interrupt status register to process
  *     @mask: a mask to apply to the interrupt status
  *     @acts: table of interrupt actions
  *     @stats: statistics counters tracking interrupt occurences
  *
  *     A table driven interrupt handler that applies a set of masks to an
  *     interrupt status word and performs the corresponding actions if the
@@ -419,7 +419,7 @@ ixpnpe_stop(struct ixpnpe_softc *sc)
 /*
  * Indicates the start of an NPE Image, in new NPE Image Library format.
- * 2 consecutive occurances indicates the end of the NPE Image Library
+ * 2 consecutive occurrences indicates the end of the NPE Image Library
  */
 #define NPE_IMAGE_MARKER 0xfeedf00d
@@ -1727,7 +1727,7 @@ struct intr_info {
  *     @mask: a mask to apply to the interrupt status
  *     @acts: table of interrupt actions
- *     @stats: statistics counters tracking interrupt occurences
+ *     @stats: statistics counters tracking interrupt occurrences
  *
  *     A table driven interrupt handler that applies a set of masks to an

Modified: head/sys/dev/msk/if_msk.c
==============================================================================